@@ -52,7 +52,7 @@ using namespace KDevelop;
 
 K_PLUGIN_FACTORY(PhpDocsFactory, registerPlugin<PhpDocsPlugin>(); )
 K_EXPORT_PLUGIN(PhpDocsFactory(KAboutData("kdevphpdocs","kdevphpdocs", ki18n("PhpDocs"),
-                                          "1.0.80", ki18n("Check PHP.net documentation"),
+                                          "1.0.82", ki18n("Check PHP.net documentation"),
                                KAboutData::License_GPL).addAuthor(ki18n("Milian Wolff"),
                                ki18n("Maintainer"), "mail@milianw.de", "http://milianw.de")))
 
@@ -195,7 +195,7 @@ QAbstractListModel* PhpDocsPlugin::indexModel() const
 KSharedPtr< IDocumentation > PhpDocsPlugin::documentationForIndex(const QModelIndex& index) const
 {
     return documentationForDeclaration(static_cast<Declaration*>(
-        index.data(PhpDocsModel::DeclarationRole).value<void *>()
+        index.data(PhpDocsModel::DeclarationRole).value<DeclarationPointer>().data()
     ));
 }
 
